#import "pyobjc.h"

NS_ASSUME_NONNULL_BEGIN

@interface OC_BuiltinPythonNumber : OC_PythonNumber {
}
@end

NS_ASSUME_NONNULL_END
